@@ -1,4 +1,4 @@
-#options(repos=structure(c(CRAN="https://mirrors.tuna.tsinghua.edu.cn/CRAN/")))
+options(repos=structure(c(CRAN="https://mirrors.tuna.tsinghua.edu.cn/CRAN/")))
 options(repos=structure(c(CRAN="http://cran.us.r-project.org")))
 if (!requireNamespace("BiocManager", quietly = TRUE))
   install.packages("BiocManager")
@@ -6,10 +6,12 @@ if (!requireNamespace("ggtree", quietly = TRUE)) BiocManager::install("ggtree")
 if (!requireNamespace("ggplot2", quietly = TRUE)) BiocManager::install("ggplot2")
 if (!requireNamespace("ggridges", quietly = TRUE)) BiocManager::install("ggridges")
 if (!requireNamespace("RColorBrewer", quietly = TRUE)) BiocManager::install("RColorBrewer")
+if (!requireNamespace("ggplotify", quietly = TRUE)) BiocManager::install("ggplotify")
 library("ggtree")
 library("RColorBrewer")
 library("ggplot2")
 library("ggridges")
+library("ggplotify")
 
 tree=read.tree("./Tree2GD_out/Phtree.nwk")
 summary=read.table("./Tree2GD_out/summarytable.txt",header = T)
@@ -42,6 +44,7 @@ summary$GDratio=as.double(lapply(summary$GDratio, function(x) as.numeric(gsub("\
 summary$GDratio=round(summary$GDratio,2)
 
 tree$edge.length=rep(1,length(tree$edge[,1]))
+
 ###################################
 dir.create("./R_plotout/")
 dir.create("./html_plot_in/")
@@ -72,20 +75,12 @@ for(F in kaks_list){
 
 p=ggtree(tree,size=rel(1),branch.length='none') %<+% summary %<+% dollop %<+% gdtype+geom_tippoint(aes(color=label),size=3)
 
-#ks.bin.count=data.frame(table(cut(all_kaks_result[which(all_kaks_result$ks<3&!is.na(all_kaks_result$ks)),]$ks,breaks=seq(0,3,by=0.02))))
-#all_kaks_result$ksbin=round(ks.bin.count[cut(all_kaks_result$ks,breaks=seq(0,3,by=0.02)),2]/max(ks.bin.count$Freq),2)
-#gradient=(max(ks.bin.count$Freq)-min(ks.bin.count$Freq))/5
 p2=p+xlim_tree(max(p$data$x)+0.5)+geom_tiplab(offset = 0, hjust = 0,size=7)+geom_rootedge(rootedge = 1)
 p3=p2+
   geom_label(aes(x=branch, label=all), fill='grey',label.size = 0.4,size = 3,colour="blue")+
   geom_text(aes(x=branch, label=up), colour='green',size = 3,vjust=-1.5,check_overlap = T)+
   geom_text(aes(x=branch, label=down), colour='red',size = 3,vjust=+2.5)+
   scale_colour_manual(values =palette(rainbow(as.numeric(length(tree$tip.label)))),guide = FALSE)+
-  #scale_fill_manual(values=c("white", "grey", "black"), guide='legend',
-  #                  name='AABBratio',
-  #                  breaks=c('(0,0.33]', '(0.33,0.66]', '(0.66,1]'),
-  #                  labels=expression(AABBratio<"33%","33%" <= AABBratio * " < 66%", AABBratio < "100%"))+
-  #geom_point2(aes(subset=!isTip& node != 1,,fill=cut(AABBratio, c(0, 0.33, 0.66, 1))), shape=21, size=4)+
   geom_label(aes(label=describe,fill=AABBratio),size = 3,vjust=+4,label.padding = unit(0.03, "lines"),label.size=0.2)+
   scale_fill_gradientn(colors = colorRampPalette(rev(brewer.pal(7,'RdYlBu')))(35),position="right",name="Color gradient")+
   geom_label(aes(label=GD,fill= GDratio+0.2),size = 3.5,vjust=2,label.padding = unit(0.1, "lines"),label.size=0.5)+
